@@ -13,7 +13,6 @@ mod modules;
 mod normalize_path;
 mod ops;
 mod ops_builtin;
-mod ops_json;
 mod ops_metrics;
 mod resources;
 mod runtime;
@@ -28,6 +27,7 @@ pub use serde_v8;
 pub use serde_v8::Buffer as ZeroCopyBuf;
 pub use serde_v8::ByteString;
 pub use serde_v8::StringOrBuffer;
+pub use serde_v8::U16String;
 pub use url;
 pub use v8;
 
@@ -44,6 +44,10 @@ pub use crate::async_cell::AsyncRefCell;
 pub use crate::async_cell::AsyncRefFuture;
 pub use crate::async_cell::RcLike;
 pub use crate::async_cell::RcRef;
+pub use crate::extensions::Extension;
+pub use crate::extensions::ExtensionBuilder;
+pub use crate::extensions::OpDecl;
+pub use crate::extensions::OpMiddlewareFn;
 pub use crate::flags::v8_set_flags;
 pub use crate::inspector::InspectorMsg;
 pub use crate::inspector::InspectorMsgKind;
@@ -65,24 +69,21 @@ pub use crate::modules::ModuleSourceFuture;
 pub use crate::modules::ModuleType;
 pub use crate::modules::NoopModuleLoader;
 pub use crate::normalize_path::normalize_path;
-pub use crate::ops::serialize_op_result;
 pub use crate::ops::Op;
 pub use crate::ops::OpAsyncFuture;
 pub use crate::ops::OpCall;
+pub use crate::ops::OpError;
 pub use crate::ops::OpFn;
 pub use crate::ops::OpId;
-pub use crate::ops::OpPayload;
 pub use crate::ops::OpResult;
 pub use crate::ops::OpState;
-pub use crate::ops::OpTable;
 pub use crate::ops::PromiseId;
 pub use crate::ops_builtin::op_close;
 pub use crate::ops_builtin::op_print;
 pub use crate::ops_builtin::op_resources;
-pub use crate::ops_json::op_async;
-pub use crate::ops_json::op_sync;
-pub use crate::ops_json::void_op_async;
-pub use crate::ops_json::void_op_sync;
+pub use crate::ops_builtin::op_void_async;
+pub use crate::ops_builtin::op_void_sync;
+pub use crate::ops_metrics::OpsTracker;
 pub use crate::resources::AsyncResult;
 pub use crate::resources::Resource;
 pub use crate::resources::ResourceId;
@@ -95,16 +96,21 @@ pub use crate::runtime::JsRuntime;
 pub use crate::runtime::RuntimeOptions;
 pub use crate::runtime::SharedArrayBufferStore;
 pub use crate::runtime::Snapshot;
-// pub use crate::runtime_modules::include_js_files!;
-pub use crate::extensions::Extension;
-pub use crate::extensions::ExtensionBuilder;
-pub use crate::extensions::OpMiddlewareFn;
-pub use crate::extensions::OpPair;
+pub use deno_ops::op;
 
 pub fn v8_version() -> &'static str {
   v8::V8::get_version()
 }
 
+/// An internal module re-exporting funcs used by the #[op] (`deno_ops`) macro
+#[doc(hidden)]
+pub mod _ops {
+  pub use super::bindings::throw_type_error;
+  pub use super::error_codes::get_error_code;
+  pub use super::ops::to_op_result;
+  pub use super::runtime::queue_async_op;
+}
+
 /// A helper macro that will return a call site in Rust code. Should be
 /// used when executing internal one-line scripts for JsRuntime lifecycle.
 ///
